#!/usr/bin/env node

import Logging from "@hibas123/logging";
import Web from "./web";
import config from "./config";
import { DatabaseManager } from "./database";
import { createServer } from "http";
import { WebsocketConnectionManager } from "./websocket";
import { LoggingTypes } from "@hibas123/logging";
import * as fs from "fs";
import * as path from "path";

if (!fs.existsSync("./databases/")) {
   fs.mkdirSync("./databases");
}

Logging.logLevel = config.dev ? LoggingTypes.Debug : LoggingTypes.Log;

let version = "unknown";
if (fs.existsSync(path.join(__dirname, "../package.json"))) {
   try {
      version = JSON.parse(
         fs.readFileSync(path.join(__dirname, "../package.json")).toString()
      ).version;
   } catch (err) {}
}

Logging.log("Starting Database version:", version);

DatabaseManager.init()
   .then(() => {
      const http = createServer(Web.callback());
      WebsocketConnectionManager.bind(http);
      const port = config.port || 5000;
      http.listen(port, () => Logging.log("WS:  Listening on port:", port));
   })
   .catch((err) => {
      Logging.error(err);
      process.exit(-1);
   });
